@@ -9,8 +9,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tclPosixStr.c,v 1.12.10.2 2009/10/21 13:54:45 dkf Exp $
  */
 
 #include "tclInt.h"
@@ -61,7 +59,7 @@ Tcl_ErrnoId(void)
 #ifdef EALIGN
     case EALIGN: return "EALIGN";
 #endif
-#if defined(EALREADY) && (!defined(EBUSY) || (EALREADY != EBUSY ))
+#if defined(EALREADY) && (!defined(EBUSY) || (EALREADY != EBUSY))
     case EALREADY: return "EALREADY";
 #endif
 #ifdef EBADE
@@ -271,7 +269,7 @@ Tcl_ErrnoId(void)
 #ifdef ENOLCK
     case ENOLCK: return "ENOLCK";
 #endif
-#ifdef ENOLINK
+#if defined(ENOLINK) && (!defined(ESOCKTNOSUPPORT) || (ESOCKTNOSUPPORT != ENOLINK))
     case ENOLINK: return "ENOLINK";
 #endif
 #ifdef ENOMEM
@@ -286,7 +284,7 @@ Tcl_ErrnoId(void)
 #ifdef ENOPKG
     case ENOPKG: return "ENOPKG";
 #endif
-#ifdef ENOPROTOOPT
+#if defined(ENOPROTOOPT) && (!defined(EPFNOSUPPORT) || (EPFNOSUPPORT != ENOPROTOOPT))
     case ENOPROTOOPT: return "ENOPROTOOPT";
 #endif
 #ifdef ENOSPC
@@ -337,7 +335,7 @@ Tcl_ErrnoId(void)
 #if defined(EOPNOTSUPP) &&  (!defined(ENOTSUP) || (ENOTSUP != EOPNOTSUPP))
     case EOPNOTSUPP: return "EOPNOTSUPP";
 #endif
-#if defined(EOVERFLOW) && ( !defined(EFBIG) || (EOVERFLOW != EFBIG) ) && ( !defined(EINVAL) || (EOVERFLOW != EINVAL) )
+#if defined(EOVERFLOW) && (!defined(EFBIG) || (EOVERFLOW != EFBIG)) && (!defined(EINVAL) || (EOVERFLOW != EINVAL))
     case EOVERFLOW: return "EOVERFLOW";
 #endif
 #ifdef EPERM
@@ -508,7 +506,7 @@ Tcl_ErrnoMsg(
 #ifdef EALIGN
     case EALIGN: return "EALIGN";
 #endif
-#if defined(EALREADY) && (!defined(EBUSY) || (EALREADY != EBUSY ))
+#if defined(EALREADY) && (!defined(EBUSY) || (EALREADY != EBUSY))
     case EALREADY: return "operation already in progress";
 #endif
 #ifdef EBADE
@@ -651,7 +649,7 @@ Tcl_ErrnoMsg(
 #endif
 #ifdef ELIBMAX
     case ELIBMAX: return
-		      "attempting to link in more shared libraries than system limit";
+	    "attempting to link in more shared libraries than system limit";
 #endif
 #ifdef ELIBSCN
     case ELIBSCN: return ".lib section in a.out corrupted";
@@ -719,8 +717,8 @@ Tcl_ErrnoMsg(
 #ifdef ENOLCK
     case ENOLCK: return "no locks available";
 #endif
-#ifdef ENOLINK
-    case ENOLINK: return "link has be severed";
+#if defined(ENOLINK) && (!defined(ESOCKTNOSUPPORT) || (ESOCKTNOSUPPORT != ENOLINK))
+    case ENOLINK: return "link has been severed";
 #endif
 #ifdef ENOMEM
     case ENOMEM: return "not enough memory";
@@ -734,7 +732,7 @@ Tcl_ErrnoMsg(
 #ifdef ENOPKG
     case ENOPKG: return "package not installed";
 #endif
-#ifdef ENOPROTOOPT
+#if defined(ENOPROTOOPT) && (!defined(EPFNOSUPPORT) || (EPFNOSUPPORT != ENOPROTOOPT))
     case ENOPROTOOPT: return "bad protocol option";
 #endif
 #ifdef ENOSPC
@@ -785,7 +783,7 @@ Tcl_ErrnoMsg(
 #if defined(EOPNOTSUPP) &&  (!defined(ENOTSUP) || (ENOTSUP != EOPNOTSUPP))
     case EOPNOTSUPP: return "operation not supported on socket";
 #endif
-#if defined(EOVERFLOW) && ( !defined(EFBIG) || (EOVERFLOW != EFBIG) ) && ( !defined(EINVAL) || (EOVERFLOW != EINVAL) )
+#if defined(EOVERFLOW) && (!defined(EFBIG) || (EOVERFLOW != EFBIG)) && (!defined(EINVAL) || (EOVERFLOW != EINVAL))
     case EOVERFLOW: return "file too big";
 #endif
 #ifdef EPERM
@@ -813,7 +811,7 @@ Tcl_ErrnoMsg(
     case EPROTO: return "protocol error";
 #endif
 #ifdef EPROTONOSUPPORT
-    case EPROTONOSUPPORT: return "protocol not suppored";
+    case EPROTONOSUPPORT: return "protocol not supported";
 #endif
 #ifdef EPROTOTYPE
     case EPROTOTYPE: return "protocol wrong type for socket";
@@ -849,7 +847,7 @@ Tcl_ErrnoMsg(
     case ERREMOTE: return "object is remote";
 #endif
 #ifdef ESHUTDOWN
-    case ESHUTDOWN: return "can't send afer socket shutdown";
+    case ESHUTDOWN: return "can't send after socket shutdown";
 #endif
 #ifdef ESOCKTNOSUPPORT
     case ESOCKTNOSUPPORT: return "socket type not supported";
@@ -906,7 +904,7 @@ Tcl_ErrnoMsg(
 #ifdef NO_STRERROR
 	return "unknown POSIX error";
 #else
-	return strerror(errno);
+	return strerror(err);
 #endif
     }
 }
