@@ -10,8 +10,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tclTomMathDecls.h,v 1.2.4.1 2010/02/07 22:16:54 nijtmans Exp $
  */
 
 #ifndef _TCLTOMMATHDECLS
@@ -79,6 +77,7 @@
 #define mp_init_copy TclBN_mp_init_copy
 #define mp_init_multi TclBN_mp_init_multi
 #define mp_init_set TclBN_mp_init_set
+#define mp_init_set_int TclBN_mp_init_set_int
 #define mp_init_size TclBN_mp_init_size
 #define mp_karatsuba_mul TclBN_mp_karatsuba_mul
 #define mp_karatsuba_sqr TclBN_mp_karatsuba_sqr
@@ -96,6 +95,7 @@
 #define mp_rshd TclBN_mp_rshd
 #define mp_s_rmap TclBNMpSRmap
 #define mp_set TclBN_mp_set
+#define mp_set_int TclBN_mp_set_int
 #define mp_shrink TclBN_mp_shrink
 #define mp_sqr TclBN_mp_sqr
 #define mp_sqrt TclBN_mp_sqrt
@@ -323,7 +323,7 @@ EXTERN int		TclBN_mp_radix_size(mp_int *a, int radix, int *size);
 #ifndef TclBN_mp_read_radix_TCL_DECLARED
 #define TclBN_mp_read_radix_TCL_DECLARED
 /* 36 */
-EXTERN int		TclBN_mp_read_radix(mp_int *a, const char *str,
+EXTERN int		TclBN_mp_read_radix(mp_int *a, CONST char *str,
 				int radix);
 #endif
 #ifndef TclBN_mp_rshd_TCL_DECLARED
@@ -451,6 +451,16 @@ EXTERN int		TclBN_s_mp_sqr(mp_int *a, mp_int *b);
 /* 60 */
 EXTERN int		TclBN_s_mp_sub(mp_int *a, mp_int *b, mp_int *c);
 #endif
+#ifndef TclBN_mp_init_set_int_TCL_DECLARED
+#define TclBN_mp_init_set_int_TCL_DECLARED
+/* 61 */
+EXTERN int		TclBN_mp_init_set_int(mp_int*a, unsigned long i);
+#endif
+#ifndef TclBN_mp_set_int_TCL_DECLARED
+#define TclBN_mp_set_int_TCL_DECLARED
+/* 62 */
+EXTERN int		TclBN_mp_set_int(mp_int*a, unsigned long i);
+#endif
 
 typedef struct TclTomMathStubs {
     int magic;
@@ -492,7 +502,7 @@ typedef struct TclTomMathStubs {
     int (*tclBN_mp_neg) (mp_int *a, mp_int *b); /* 33 */
     int (*tclBN_mp_or) (mp_int *a, mp_int *b, mp_int *c); /* 34 */
     int (*tclBN_mp_radix_size) (mp_int *a, int radix, int *size); /* 35 */
-    int (*tclBN_mp_read_radix) (mp_int *a, const char *str, int radix); /* 36 */
+    int (*tclBN_mp_read_radix) (mp_int *a, CONST char *str, int radix); /* 36 */
     void (*tclBN_mp_rshd) (mp_int *a, int shift); /* 37 */
     int (*tclBN_mp_shrink) (mp_int *a); /* 38 */
     void (*tclBN_mp_set) (mp_int *a, mp_digit b); /* 39 */
@@ -517,6 +527,8 @@ typedef struct TclTomMathStubs {
     int (*tclBN_s_mp_mul_digs) (mp_int *a, mp_int *b, mp_int *c, int digs); /* 58 */
     int (*tclBN_s_mp_sqr) (mp_int *a, mp_int *b); /* 59 */
     int (*tclBN_s_mp_sub) (mp_int *a, mp_int *b, mp_int *c); /* 60 */
+    int (*tclBN_mp_init_set_int) (mp_int*a, unsigned long i); /* 61 */
+    int (*tclBN_mp_set_int) (mp_int*a, unsigned long i); /* 62 */
 } TclTomMathStubs;
 
 #ifdef __cplusplus
@@ -777,6 +789,14 @@ extern TclTomMathStubs *tclTomMathStubsPtr;
 #define TclBN_s_mp_sub \
 	(tclTomMathStubsPtr->tclBN_s_mp_sub) /* 60 */
 #endif
+#ifndef TclBN_mp_init_set_int
+#define TclBN_mp_init_set_int \
+	(tclTomMathStubsPtr->tclBN_mp_init_set_int) /* 61 */
+#endif
+#ifndef TclBN_mp_set_int
+#define TclBN_mp_set_int \
+	(tclTomMathStubsPtr->tclBN_mp_set_int) /* 62 */
+#endif
 
 #endif /* defined(USE_TCL_STUBS) && !defined(USE_TCL_STUB_PROCS) */
 
